# Block Types Data

Namespace: `core/blocks`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../../packages/blocks/src/store/selectors.js) -->

<a name="getBlockStyles" href="#getBlockStyles">#</a> **getBlockStyles**

Returns block styles by block name.

_Parameters_

-   _state_ `Object`: Data state.
-   _name_ `string`: Block type name.

_Returns_

-   `Array?`: Block Styles.

<a name="getBlockSupport" href="#getBlockSupport">#</a> **getBlockSupport**

Returns the block support value for a feature, if defined.

_Parameters_

-   _state_ `Object`: Data state.
-   _nameOrType_ `(string|Object)`: Block name or type object
-   _feature_ `string`: Feature to retrieve
-   _defaultSupports_ `*`: Default value to return if not explicitly defined

_Returns_

-   `?*`: Block support value

<a name="getBlockType" href="#getBlockType">#</a> **getBlockType**

Returns a block type by name.

_Parameters_

-   _state_ `Object`: Data state.
-   _name_ `string`: Block type name.

_Returns_

-   `Object?`: Block Type.

<a name="getBlockTypes" href="#getBlockTypes">#</a> **getBlockTypes**

Returns all the available block types.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `Array`: Block Types.

<a name="getBlockVariations" href="#getBlockVariations">#</a> **getBlockVariations**

Returns block variations by block name.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.
-   _scope_ `[WPBlockVariationScope]`: Block variation scope name.

_Returns_

-   `(WPBlockVariation[]|void)`: Block variations.

<a name="getCategories" href="#getCategories">#</a> **getCategories**

Returns all the available categories.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `WPBlockCategory[]`: Categories list.

<a name="getChildBlockNames" href="#getChildBlockNames">#</a> **getChildBlockNames**

Returns an array with the child blocks of a given block.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `Array`: Array of child block names.

<a name="getCollections" href="#getCollections">#</a> **getCollections**

Returns all the available collections.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `Object`: Collections list.

<a name="getDefaultBlockName" href="#getDefaultBlockName">#</a> **getDefaultBlockName**

Returns the name of the default block name.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Default block name.

<a name="getDefaultBlockVariation" href="#getDefaultBlockVariation">#</a> **getDefaultBlockVariation**

Returns the default block variation for the given block type.
When there are multiple variations annotated as the default one,
the last added item is picked. This simplifies registering overrides.
When there is no default variation set, it returns the first item.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.
-   _scope_ `[WPBlockVariationScope]`: Block variation scope name.

_Returns_

-   `?WPBlockVariation`: The default block variation.

<a name="getFreeformFallbackBlockName" href="#getFreeformFallbackBlockName">#</a> **getFreeformFallbackBlockName**

Returns the name of the block for handling non-block content.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling non-block content.

<a name="getGroupingBlockName" href="#getGroupingBlockName">#</a> **getGroupingBlockName**

Returns the name of the block for handling unregistered blocks.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling unregistered blocks.

<a name="getUnregisteredFallbackBlockName" href="#getUnregisteredFallbackBlockName">#</a> **getUnregisteredFallbackBlockName**

Returns the name of the block for handling unregistered blocks.

_Parameters_

-   _state_ `Object`: Data state.

_Returns_

-   `string?`: Name of the block for handling unregistered blocks.

<a name="hasBlockSupport" href="#hasBlockSupport">#</a> **hasBlockSupport**

Returns true if the block defines support for a feature, or false otherwise.

_Parameters_

-   _state_ `Object`: Data state.
-   _nameOrType_ `(string|Object)`: Block name or type object.
-   _feature_ `string`: Feature to test.
-   _defaultSupports_ `boolean`: Whether feature is supported by default if not explicitly defined.

_Returns_

-   `boolean`: Whether block supports feature.

<a name="hasChildBlocks" href="#hasChildBlocks">#</a> **hasChildBlocks**

Returns a boolean indicating if a block has child blocks or not.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `boolean`: True if a block contains child blocks and false otherwise.

<a name="hasChildBlocksWithInserterSupport" href="#hasChildBlocksWithInserterSupport">#</a> **hasChildBlocksWithInserterSupport**

Returns a boolean indicating if a block has at least one child block with inserter support.

_Parameters_

-   _state_ `Object`: Data state.
-   _blockName_ `string`: Block type name.

_Returns_

-   `boolean`: True if a block contains at least one child blocks with inserter support and false otherwise.

<a name="isMatchingSearchTerm" href="#isMatchingSearchTerm">#</a> **isMatchingSearchTerm**

Returns true if the block type by the given name or object value matches a
search term, or false otherwise.

_Parameters_

-   _state_ `Object`: Blocks state.
-   _nameOrType_ `(string|Object)`: Block name or type object.
-   _searchTerm_ `string`: Search term by which to filter.

_Returns_

-   `Object[]`: Whether block type matches search term.

<!-- END TOKEN(Autogenerated selectors|../../../../packages/blocks/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../../packages/blocks/src/store/actions.js) -->

<a name="addBlockCollection" href="#addBlockCollection">#</a> **addBlockCollection**

Returns an action object used to add block collections

_Parameters_

-   _namespace_ `string`: The namespace of the blocks to put in the collection
-   _title_ `string`: The title to display in the block inserter
-   _icon_ `Object`: (optional) The icon to display in the block inserter

_Returns_

-   `Object`: Action object.

<a name="addBlockStyles" href="#addBlockStyles">#</a> **addBlockStyles**

Returns an action object used in signalling that new block styles have been added.

_Parameters_

-   _blockName_ `string`: Block name.
-   _styles_ `Array|Object`: Block styles.

_Returns_

-   `Object`: Action object.

<a name="addBlockTypes" href="#addBlockTypes">#</a> **addBlockTypes**

Returns an action object used in signalling that block types have been added.

_Parameters_

-   _blockTypes_ `Array|Object`: Block types received.

_Returns_

-   `Object`: Action object.

<a name="addBlockVariations" href="#addBlockVariations">#</a> **addBlockVariations**

Returns an action object used in signalling that new block variations have been added.

_Parameters_

-   _blockName_ `string`: Block name.
-   _variations_ `WPBlockVariation|WPBlockVariation[]`: Block variations.

_Returns_

-   `Object`: Action object.

<a name="removeBlockCollection" href="#removeBlockCollection">#</a> **removeBlockCollection**

Returns an action object used to remove block collections

_Parameters_

-   _namespace_ `string`: The namespace of the blocks to put in the collection

_Returns_

-   `Object`: Action object.

<a name="removeBlockStyles" href="#removeBlockStyles">#</a> **removeBlockStyles**

Returns an action object used in signalling that block styles have been removed.

_Parameters_

-   _blockName_ `string`: Block name.
-   _styleNames_ `Array|string`: Block style names.

_Returns_

-   `Object`: Action object.

<a name="removeBlockTypes" href="#removeBlockTypes">#</a> **removeBlockTypes**

Returns an action object used to remove a registered block type.

_Parameters_

-   _names_ `string|Array`: Block name.

_Returns_

-   `Object`: Action object.

<a name="removeBlockVariations" href="#removeBlockVariations">#</a> **removeBlockVariations**

Returns an action object used in signalling that block variations have been removed.

_Parameters_

-   _blockName_ `string`: Block name.
-   _variationNames_ `string|string[]`: Block variation names.

_Returns_

-   `Object`: Action object.

<a name="setCategories" href="#setCategories">#</a> **setCategories**

Returns an action object used to set block categories.

_Parameters_

-   _categories_ `Object[]`: Block categories.

_Returns_

-   `Object`: Action object.

<a name="setDefaultBlockName" href="#setDefaultBlockName">#</a> **setDefaultBlockName**

Returns an action object used to set the default block name.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

<a name="setFreeformFallbackBlockName" href="#setFreeformFallbackBlockName">#</a> **setFreeformFallbackBlockName**

Returns an action object used to set the name of the block used as a fallback
for non-block content.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

<a name="setGroupingBlockName" href="#setGroupingBlockName">#</a> **setGroupingBlockName**

Returns an action object used to set the name of the block used
when grouping other blocks
eg: in "Group/Ungroup" interactions

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

<a name="setUnregisteredFallbackBlockName" href="#setUnregisteredFallbackBlockName">#</a> **setUnregisteredFallbackBlockName**

Returns an action object used to set the name of the block used as a fallback
for unregistered blocks.

_Parameters_

-   _name_ `string`: Block name.

_Returns_

-   `Object`: Action object.

<a name="updateCategory" href="#updateCategory">#</a> **updateCategory**

Returns an action object used to update a category.

_Parameters_

-   _slug_ `string`: Block category slug.
-   _category_ `Object`: Object containing the category properties that should be updated.

_Returns_

-   `Object`: Action object.


<!-- END TOKEN(Autogenerated actions|../../../../packages/blocks/src/store/actions.js) -->
