# Keycodes

Keycodes utilities for WordPress, used to check the key pressed in events like `onKeyDown`. Contains keycodes constants for keyboard keys like `DOWN`, `UP`, `ENTER`, etc.

## Installation

Install the module

```bash
npm install @wordpress/keycodes --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for ES2015+ such as lower versions of IE then using [core-js](https://github.com/zloirock/core-js) or [@babel/polyfill](https://babeljs.io/docs/en/next/babel-polyfill) will add support for these methods. Learn more about it in [Babel docs](https://babeljs.io/docs/en/next/caveats)._

## Usage

Check which key was used in an `onKeyDown` event:

```js
import { DOWN, ENTER } from '@wordpress/keycodes';

// [...]

onKeyDown( event ) {
	const { keyCode } = event;
	
	if ( keyCode === DOWN ) {
		alert( 'You pressed the down arrow!' );
	} else if ( keyCode === ENTER ) {
		alert( 'You pressed the enter key!' );
	} else {
		alert( 'You pressed another key.' );
	}
}
```

## API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="ALT" href="#ALT">#</a> **ALT**

Keycode for ALT key.

<a name="BACKSPACE" href="#BACKSPACE">#</a> **BACKSPACE**

Keycode for BACKSPACE key.

<a name="COMMAND" href="#COMMAND">#</a> **COMMAND**

Keycode for COMMAND/META key.

<a name="CTRL" href="#CTRL">#</a> **CTRL**

Keycode for CTRL key.

<a name="DELETE" href="#DELETE">#</a> **DELETE**

Keycode for DELETE key.

<a name="displayShortcut" href="#displayShortcut">#</a> **displayShortcut**

An object that contains functions to display shortcuts.

_Usage_

```js
// Assuming macOS:
displayShortcut.primary( 'm' );
// "⌘M"
```

_Type_

-   `WPModifierHandler<WPKeyHandler<string>>` Keyed map of functions to display shortcuts.

<a name="displayShortcutList" href="#displayShortcutList">#</a> **displayShortcutList**

Return an array of the parts of a keyboard shortcut chord for display.

_Usage_

```js
// Assuming macOS:
displayShortcutList.primary( 'm' );
// [ "⌘", "M" ]
```

_Type_

-   `WPModifierHandler<WPKeyHandler<string[]>>` Keyed map of functions to shortcut sequences.

<a name="DOWN" href="#DOWN">#</a> **DOWN**

Keycode for DOWN key.

<a name="ENTER" href="#ENTER">#</a> **ENTER**

Keycode for ENTER key.

<a name="ESCAPE" href="#ESCAPE">#</a> **ESCAPE**

Keycode for ESCAPE key.

<a name="F10" href="#F10">#</a> **F10**

Keycode for F10 key.

<a name="isKeyboardEvent" href="#isKeyboardEvent">#</a> **isKeyboardEvent**

An object that contains functions to check if a keyboard event matches a
predefined shortcut combination.

_Usage_

```js
// Assuming an event for ⌘M key press:
isKeyboardEvent.primary( event, 'm' );
// true
```

_Type_

-   `WPModifierHandler<WPEventKeyHandler>` Keyed map of functions to match events.

<a name="LEFT" href="#LEFT">#</a> **LEFT**

Keycode for LEFT key.

<a name="modifiers" href="#modifiers">#</a> **modifiers**

Object that contains functions that return the available modifier
depending on platform.

_Type_

-   `WPModifierHandler< ( isApple: () => boolean ) => WPModifierPart[]>` 

<a name="rawShortcut" href="#rawShortcut">#</a> **rawShortcut**

An object that contains functions to get raw shortcuts.

These are intended for user with the KeyboardShortcuts.

_Usage_

```js
// Assuming macOS:
rawShortcut.primary( 'm' )
// "meta+m""
```

_Type_

-   `WPModifierHandler<WPKeyHandler<string>>` Keyed map of functions to raw shortcuts.

<a name="RIGHT" href="#RIGHT">#</a> **RIGHT**

Keycode for RIGHT key.

<a name="SHIFT" href="#SHIFT">#</a> **SHIFT**

Keycode for SHIFT key.

<a name="shortcutAriaLabel" href="#shortcutAriaLabel">#</a> **shortcutAriaLabel**

An object that contains functions to return an aria label for a keyboard
shortcut.

_Usage_

```js
// Assuming macOS:
shortcutAriaLabel.primary( '.' );
// "Command + Period"
```

_Type_

-   `WPModifierHandler<WPKeyHandler<string>>` Keyed map of functions to shortcut ARIA labels.

<a name="SPACE" href="#SPACE">#</a> **SPACE**

Keycode for SPACE key.

<a name="TAB" href="#TAB">#</a> **TAB**

Keycode for TAB key.

<a name="UP" href="#UP">#</a> **UP**

Keycode for UP key.

<a name="ZERO" href="#ZERO">#</a> **ZERO**

Keycode for ZERO key.


<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
